@@ -30,6 +30,7 @@
 #include <QJsonObject>
 #include <QJsonArray>
 #include <QDate>
+#include <QSet>
 
 #include "discovercommon_export.h"
 #include "PackageState.h"
@@ -157,7 +158,7 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
         virtual QString longDescription() = 0;
 
         virtual QString origin() const = 0;
-        QString displayOrigin() const;
+        virtual QString displayOrigin() const;
         virtual QString section() = 0;
         virtual QString author() const = 0;
 
@@ -215,6 +216,8 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
          */
         virtual QDate releaseDate() const = 0;
 
+        virtual QSet<QString> alternativeAppstreamIds() const { return {}; }
+
     public Q_SLOTS:
         virtual void fetchScreenshots();
         virtual void fetchChangelog() = 0;
